@@ -1,11 +1,8 @@
 package Scaffold::Uaf::Authenticate;
 
-use 5.008;
-use strict;
-use warnings;
-
 our $VERSION = '0.03';
 
+use 5.8.8;
 use Try::Tiny;
 use Scaffold::Uaf::User;
 
@@ -51,7 +48,7 @@ sub uaf_is_valid {
     $ip = $self->scaffold->request->address;
 
     if ($token = $self->stash->cookies->get(TOKEN_ID)) {
-        
+
         $new_token = $token->value;
         $old_ip = $self->scaffold->session->get('uaf_remote_ip') || '';
         $old_token = $self->scaffold->session->get('uaf_token') || '';
@@ -112,7 +109,7 @@ sub uaf_invalidate {
 sub uaf_set_token {
     my ($self, $user) = @_;
 
-    my $salt = $user->attribute('salt');
+    my $salt = $user->attribute('salt') || '';
     my $token = encrypt($user->username, ':', time(), ':', $salt, $$);
 
     $self->stash->cookies->set(
@@ -327,11 +324,13 @@ These accessors return the corresponding config items.
  Scaffold::Constants
  Scaffold::Engine
  Scaffold::Handler
+ Scaffold::Handler::Default
  Scaffold::Handler::Favicon
  Scaffold::Handler::Robots
  Scaffold::Handler::Static
  Scaffold::Lockmgr
  Scaffold::Lockmgr::KeyedMutex
+ Scaffold::Lockmgr::UnixMutex
  Scaffold::Plugins
  Scaffold::Render
  Scaffold::Render::Default
